summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql/src/select.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql/src/select.c')
-rw-r--r--kexi/3rdparty/kexisql/src/select.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/kexi/3rdparty/kexisql/src/select.c b/kexi/3rdparty/kexisql/src/select.c
index 7ae02d33..cc13aec8 100644
--- a/kexi/3rdparty/kexisql/src/select.c
+++ b/kexi/3rdparty/kexisql/src/select.c
@@ -1634,7 +1634,7 @@ substExprList(ExprList *pList, int iTable, ExprList *pEList){
*/
static int flattenSubquery(
Parse *pParse, /* The parsing context */
- Select *p, /* The parent or outer SELECT statement */
+ Select *p, /* The tqparent or outer SELECT statement */
int iFrom, /* Index in p->pSrc->a[] of the inner subquery */
int isAgg, /* True if outer SELECT uses aggregate functions */
int subqueryIsAgg /* True if the subquery uses aggregate functions */
@@ -1707,7 +1707,7 @@ static int flattenSubquery(
** the FROM clause of the outer query. Before doing this, remember
** the cursor number for the original outer query FROM element in
** iParent. The iParent cursor will never be used. Subsequent code
- ** will scan expressions looking for iParent references and replace
+ ** will scan expressions looking for iParent references and tqreplace
** those references with expressions that resolve to the subquery FROM
** elements we are now copying in.
*/
@@ -1985,10 +1985,10 @@ static int simpleMinMaxQuery(Parse *pParse, Select *p, int eDest, int iParm){
** This routine does NOT free the Select structure passed in. The
** calling function needs to do that.
**
** The pParent, parentTab, and *pParentAgg fields are filled in if this
** SELECT is a subquery. This routine may try to combine this SELECT
** with its parent to form a single flat query. In so doing, it might
** change the parent query from a non-aggregate to an aggregate query.
** For that reason, the pParentAgg flag is passed as a pointer, so it
** can be changed.
**
@@ -2003,7 +2003,7 @@ static int simpleMinMaxQuery(Parse *pParse, Select *p, int eDest, int iParm){
** pParent will be NULL. During the processing of the outer query, this
** routine is called recursively to handle the subquery. For the recursive
** call, pParent will point to the outer query. Because the subquery is
** the second element in a three-way join, the parentTab parameter will
** be 1 (the 2nd value of a 0-indexed array.)
*/
int sqliteSelect(
@@ -2012,7 +2012,7 @@ int sqliteSelect(
int eDest, /* How to dispose of the results */
int iParm, /* A parameter used by the eDest disposal method */
Select *pParent, /* Another SELECT for which this is a sub-query */
- int parentTab, /* Index in pParent->pSrc of this query */
+ int tqparentTab, /* Index in pParent->pSrc of this query */
int *pParentAgg /* True if pParent uses aggregate functions */
){
int i;
@@ -2228,11 +2228,11 @@ int sqliteSelect(
goto select_end;
}
/* Check to see if this is a subquery that can be "flattened" into its parent.
** If flattening is a possiblity, do so and return immediately.
*/
if( pParent && pParentAgg &&
- flattenSubquery(pParse, pParent, parentTab, *pParentAgg, isAgg) ){
+ flattenSubquery(pParse, pParent, tqparentTab, *pParentAgg, isAgg) ){
if( isAgg ) *pParentAgg = 1;
return rc;
}
@@ -2409,15 +2409,15 @@ int sqliteSelect(
}
/* If this was a subquery, we have now converted the subquery into a
** temporary table. So delete the subquery structure from the parent
** to prevent this subquery from being evaluated again and to force the
** the use of the temporary table.
*/
if( pParent ){
- assert( pParent->pSrc->nSrc>parentTab );
- assert( pParent->pSrc->a[parentTab].pSelect==p );
+ assert( pParent->pSrc->nSrc>tqparentTab );
+ assert( pParent->pSrc->a[tqparentTab].pSelect==p );
sqliteSelectDelete(p);
- pParent->pSrc->a[parentTab].pSelect = 0;
+ pParent->pSrc->a[tqparentTab].pSelect = 0;
}
/* The SELECT was successfully coded. Set the return code to 0
@@ -1985,10 +1985,10 @@ static int simpleMinMaxQuery(Parse *pParse, Select *p, int eDest, int iParm){
** calling function needs to do that.
**
-** The pParent, parentTab, and *pParentAgg fields are filled in if this
+** The pParent, tqparentTab, and *pParentAgg fields are filled in if this
** SELECT is a subquery. This routine may try to combine this SELECT
@@ -1985,10 +1985,10 @@ static int simpleMinMaxQuery(Parse *pParse, Select *p, int eDest, int iParm){
** SELECT is a subquery. This routine may try to combine this SELECT
-** with its parent to form a single flat query. In so doing, it might
-** change the parent query from a non-aggregate to an aggregate query.
+** with its tqparent to form a single flat query. In so doing, it might
+** change the tqparent query from a non-aggregate to an aggregate query.
** For that reason, the pParentAgg flag is passed as a pointer, so it
** can be changed.
@@ -2003,7 +2003,7 @@ static int simpleMinMaxQuery(Parse *pParse, Select *p, int eDest, int iParm){
** routine is called recursively to handle the subquery. For the recursive
** call, pParent will point to the outer query. Because the subquery is
-** the second element in a three-way join, the parentTab parameter will
+** the second element in a three-way join, the tqparentTab parameter will
** be 1 (the 2nd value of a 0-indexed array.)
*/
@@ -2228,11 +2228,11 @@ int sqliteSelect(
goto select_end;
}
- /* Check to see if this is a subquery that can be "flattened" into its parent.
+ /* Check to see if this is a subquery that can be "flattened" into its tqparent.
** If flattening is a possiblity, do so and return immediately.
*/
@@ -2409,15 +2409,15 @@ int sqliteSelect(
}
/* If this was a subquery, we have now converted the subquery into a
- ** temporary table. So delete the subquery structure from the parent
+ ** temporary table. So delete the subquery structure from the tqparent
** to prevent this subquery from being evaluated again and to force the
** the use of the temporary table.